#ifndef exif_dll_h
#define exif_dll_h

extern "C" {

// exported functions are embeded in a namespace, allowing to:
// - do not polute global namesapce
// - make sure that the implementation .CPP works exactly
//   as .H spefies

namespace exif_dll
{
   // reads EXIF information from a file, returns false if failed; all EXIF
   // information is mounted in memory. EXIF information can be wrote back
   // to a file using write_file()
   bool _export WINAPI read_file(const char* file) ;
   // writes EXIF information back to a file, copying image data from
   // the file previously read with read_file(); note that file_name can
   // be the same as the one given to read_file().
   // The value of is_modified() method can be checked to know wether the file needs to
   // be rewritten or not
   bool _export WINAPI write_file(const char* file) ;
   // returns image description from EXIF data; can be empty
   void _export WINAPI get_image_description(char *image_description) ;
   // changes image description; if set empty, the corresponding EXIF data
   // is removed from memory
   void _export WINAPI set_image_description(const char* image_description) ;
   // gets artist string from EXIF
   void _export WINAPI get_artist(char* artist) ;
   // changes artist string
   void _export WINAPI set_artist(const char* artist) ;
   // gets copyright string from EXIF
   void _export WINAPI get_copyright(char* copyright) ;
   // changes copyright
   void _export WINAPI set_copyright(const char* copyright) ;
   // changes user comment
   void _export WINAPI set_user_comment(const char* user_comment) ;
   // gets user comment from EXIF
   void _export WINAPI get_user_comment(char *user_comment) ;
   // gets original date and time
   bool _export WINAPI get_date_time_original(int& year, int& month, int& day
                              ,int& hour, int& minute, int& second) ;
   // changes original date and time
   void _export WINAPI set_date_time_original(int year, int month, int day
                              ,int hour, int minute, int second) ;
   // get image width
   long _export WINAPI get_image_width() ;
   // get image height
   long _export WINAPI get_image_height() ;
   // get focal length in mm, -1 if undefined (not found in EXIF data)
   double _export WINAPI get_focal_length() ;
   // get focal length equivalent assuming a 35mm film camera in millimeters,
   // 0 if unknown, -1.0 if undefined (not found in EXIF data)
   int _export WINAPI get_focal_length_35_mm() ;
   // get focal plane X resolution in CCD's pixel units, -1.0 if undefined (not found in EXIF data)
   double _export WINAPI get_focal_plane_X_resolution() ;
   // get focal plane Y resolution in CCD's pixel units, -1.0 if undefined (not found in EXIF data)
   double _export WINAPI get_focal_plane_Y_resolution() ;
   // get focal plane resolution unit '1' means no-unit, '2' inch, '3' centimeter
   // -1 if undefined (not found in EXIF data)
   int _export WINAPI get_focal_plane_resolution_unit() ;
   // return true if the file read contains a thumbnail image
   bool _export WINAPI has_thumbnail_image() ;
   // removes thumbnail data from EXIF
   void _export WINAPI clear_thumbnail_image() ;
   // return true if one of the set_XXX() or clear_thumbnail_image() method has changed something
   // to the EXIF data
   bool _export WINAPI is_modified() ;
}

}

#endif

