unit utrace;

interface

uses
  SysUtils, Graphics, Types, 
  uphoto;

type

  TTrace = class
  private
    fX, fY, fZ : array of real;
    FNbPoint : integer;
    FCoupure : array of boolean;
    FEpaisseur: integer;
    FCouleur: TColor;
    procedure SetCouleur(const Value: TColor);
    procedure SetEpaisseur(const Value: integer);
    procedure SetNbPoint(const Value: integer);
  public
    property Couleur : TColor read FCouleur write SetCouleur;
    property Epaisseur : integer read FEpaisseur write SetEpaisseur;
    property NbPoint : integer read FNbPoint write SetNbPoint;
    constructor Create;
    destructor Destroy; override;
    procedure LoadFromFile(FileName : TFileName);
    procedure Dessiner(Canvas : TCanvas; Photo : TPhoto);
  end;

implementation

{ TTrace }

constructor TTrace.Create;
begin
  Couleur:=clBlack;
  Epaisseur:=1;
  FNbPoint:=0;
end;

procedure TTrace.Dessiner(Canvas: TCanvas; Photo: TPhoto);
var
  I : integer;
  Pts : TPoint;
begin
  Canvas.Pen.Color:=Couleur;
  Canvas.Pen.Width:=Epaisseur;
  for I:=0 to FNbPoint-1 do
  begin
    Pts:=Photo.Terrain2Photo(fX[I],fY[I],fZ[I]);
    if FCoupure[I] then
      Canvas.MoveTo(Pts.X, Pts.Y)
    else
      Canvas.LineTo(Pts.X, Pts.Y);
  end;
end;

destructor TTrace.Destroy;
begin
  inherited Destroy;
end;

procedure TTrace.LoadFromFile(FileName: TFileName);
var
  F : textFile;
  S, SX, SY, SZ : string;
begin
  AssignFile(F,FileName);
  reset(F);
  try
    SetLength(fX,0);
    SetLength(fY,0);
    SetLength(fZ,0);
    SetLength(FCoupure,0);
    FNbPoint:=0;
    while not Eof(F) do
    begin
      Readln(F, S);
      if UpperCase(S)='COUPURE' then
        FCoupure[FNbPoint-1]:=true
      else
      try
        SX:=Copy(S,1,pos(#9,S)-1);
        Delete(S,1,pos(#9,S));
        SY:=Copy(S,1,pos(#9,S)-1);
        Delete(S,1,pos(#9,S));
        SZ:=S;
        inc(FNbPoint);
        SetLength(fX,FNbPoint);
        SetLength(fY,FNbPoint);
        SetLength(fZ,FNbPoint);
        SetLength(FCoupure,FNbPoint);
        FCoupure[FNbPoint-1]:=false;
        try
          fX[FNbPoint-1]:=StrToFloat(SX);
          fY[FNbPoint-1]:=StrToFloat(SY);
          fZ[FNbPoint-1]:=StrToFloat(SZ)/1000;
        except // si les conversions plantent, on enlve le point
          dec(FNbPoint);
        end;
      except // on arrive ici si l'analyse de la ligne n'a pas fonctionne,
             // dans ce cas, on l'ignore
      end;
    end;
  finally
    closeFile(F);
  end;
  if FNbPoint>0 then
    FCoupure[0]:=true;
end;

procedure TTrace.SetCouleur(const Value: TColor);
begin
  FCouleur := Value;
end;

procedure TTrace.SetEpaisseur(const Value: integer);
begin
  FEpaisseur := Value;
end;

procedure TTrace.SetNbPoint(const Value: integer);
begin
  FNbPoint := Value;
end;

end.
